@@ -315,12 +315,10 @@ class TaskScheduler:
 
     @property
     def availabe_slots(self):
-        print(now(), "Assigned tasks", self.assigned_tasks)
         available = {}
         for ipt, tasks in self.assigned_tasks.items():
             assigned_tasks = {t for t, v in tasks.items()
                               if v}
-            print(now(), "Available slots assigned task", assigned_tasks)
             if len(assigned_tasks) == self.lnproc:
                 available[ipt] = False 
             else:
